import locale

from django import template
from django.utils.timezone import datetime

locale.setlocale(locale.LC_ALL, '')
register = template.Library()


@register.filter()
def currency(value):
    return locale.currency(value, symbol=False, grouping=True)


@register.assignment_tag()
def get_current_year():
    return datetime.now().year


@register.assignment_tag()
def get_current_month():
    return datetime.now().month



"""Tests for the utils of the account_keeping app."""
import datetime

from django.test import TestCase

from .. import utils


class GetDateTestCase(TestCase):
    """Tests for the ``get_date`` function."""
    longMessage = True

    def test_function(self):
        result = utils.get_date('2014-01-01')
        self.assertEqual(result, datetime.datetime(2014, 1, 1))
